Crate gsp_wasm_interface

Crate gsp_wasm_interface 

Types and traits for interfacing between the host and the wasm runtime.

Re-exports

pub use sp_wasm_interface_common as common;

Macros

if_wasmtime_is_enabled

Structs

Caller
ExtendedHostFunctions
A wrapper which merges two sets of host functions, and allows the second set to override the host functions from the first set.
Pointer
Type to represent a pointer in wasm at the host.
Signature
The signature of a function.
StoreData

Enums

ReturnValue
Typed value that can be returned from a function.
Value
Values supported by Substrate on the boundary between host/Wasm.
ValueType
Value types supported by Substrate on the boundary between host/Wasm.

Traits

Function
Something that provides a function implementation on the host for a wasm function.
FunctionContext
Context used by Function to interact with the allocator and the memory of the wasm instance.
HostFunctions
Something that provides implementations for host functions.
IntoValue
Something that can be converted into a wasm compatible Value.
MaybeRefUnwindSafe
A trait that requires RefUnwindSafe when feature = std.
PointerType
Something that can be wrapped in a wasm Pointer.
TryFromValue
Something that can be created from a wasm Value.
WasmTy
A trait for types directly usable at the WASM FFI boundary without any conversion at all.

Type Aliases

HostPointer
Host pointer sized for both 32-bit and 64-bit architectures.
MemoryId
Sandbox memory identifier.
Result
Result type used by traits in this crate.
WordSize
The word size used in wasm. Normally known as usize in Rust.